# coding: utf-8

"""
    

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat

from six import iteritems


class PhysicalLocation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'lat': 'float',
        'lon': 'float',
        'pk': 'PhysicalLocationPK'
    }

    attribute_map = {
        'name': 'name',
        'lat': 'lat',
        'lon': 'lon',
        'pk': 'pk'
    }

    def __init__(self, name=None, lat=None, lon=None, pk=None):
        """
        PhysicalLocation - a model defined in Swagger
        """

        self._name = None
        self._lat = None
        self._lon = None
        self._pk = None

        self.name = name
        self.lat = lat
        self.lon = lon
        self.pk = pk

    @property
    def name(self):
        """
        Gets the name of this PhysicalLocation.

        :return: The name of this PhysicalLocation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PhysicalLocation.

        :param name: The name of this PhysicalLocation.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def lat(self):
        """
        Gets the lat of this PhysicalLocation.

        :return: The lat of this PhysicalLocation.
        :rtype: float
        """
        return self._lat

    @lat.setter
    def lat(self, lat):
        """
        Sets the lat of this PhysicalLocation.

        :param lat: The lat of this PhysicalLocation.
        :type: float
        """
        if lat is None:
            raise ValueError("Invalid value for `lat`, must not be `None`")

        self._lat = lat

    @property
    def lon(self):
        """
        Gets the lon of this PhysicalLocation.

        :return: The lon of this PhysicalLocation.
        :rtype: float
        """
        return self._lon

    @lon.setter
    def lon(self, lon):
        """
        Sets the lon of this PhysicalLocation.

        :param lon: The lon of this PhysicalLocation.
        :type: float
        """
        if lon is None:
            raise ValueError("Invalid value for `lon`, must not be `None`")

        self._lon = lon

    @property
    def pk(self):
        """
        Gets the pk of this PhysicalLocation.

        :return: The pk of this PhysicalLocation.
        :rtype: PhysicalLocationPK
        """
        return self._pk

    @pk.setter
    def pk(self, pk):
        """
        Sets the pk of this PhysicalLocation.

        :param pk: The pk of this PhysicalLocation.
        :type: PhysicalLocationPK
        """
        if pk is None:
            raise ValueError("Invalid value for `pk`, must not be `None`")

        self._pk = pk

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PhysicalLocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
